@@ -412,7 +412,7 @@ struct row_column* scotch(struct row_column *cur, ...)
 
   va_start(b, cur) ;
 
-  if ( cur==0 )
+  if ( cur==NULL )
     {
       fprintf(stderr,"You must have something to scotch %s:%d\n",
 	      __FILE__,__LINE__) ;
@@ -421,14 +421,14 @@ struct row_column* scotch(struct row_column *cur, ...)
   type = cur->type ;
   if ( type==A_COLUMN ) newtype = A_LINE ;
   else  newtype = A_COLUMN ;
-  last = 0 ;
-  first = 0 ; /* Only to remove a GCC warning */
+  last = NULL ;
+  first = NULL ; /* Only to remove a GCC warning */
   do
     {
       newone = (struct row_column *) malloc( sizeof(*newone) ) ;
       newone->type = newtype ;
       newone->in = cur ;
-      newone->next = 0 ;
+      newone->next = NULL ;
       if ( last ) last->next = newone ;
       else first = newone ;
       last = newone ;
@@ -589,9 +589,9 @@ void posit_button(struct row_column *r, int x, int y)
 /* Compute the minimum height */
 int compute_height(struct row_column *r)
 {
-  (void)minimumheight((struct moving_button*)0,INIT_MINIMUM) ;
+  (void)minimumheight((struct moving_button*)NULL,INIT_MINIMUM) ;
   walkrowcol(r, (void (*)())minimumheight,COMPUTE_MINIMUM,0,0,0) ;
-  return( minimumheight((struct moving_button*)0,GIVE_MINIMUM) ) ;
+  return( minimumheight((struct moving_button*)NULL,GIVE_MINIMUM) ) ;
 }
 /* Stretch to minimum height or 2* 3* ... minimum height */
 void compute_stretch(struct row_column *r, int minimum)
